#
# spec file for package ini4j
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ini4j
Version:        0.5.4
Release:        1.5
Summary:        Java API for handling Windows ini file format
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://www.ini4j.org/
Source0:        https://downloads.sourceforge.net/%{name}/%{version}/%{name}-%{version}-src.zip
Source1:        %{name}.build.xml
Patch0:         ini4j-java8-compat.patch
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  unzip
Requires:       java
BuildArch:      noarch

%description
The [ini4j] is a simple Java API for handling configuration files in
Windows .ini format. Additionally, the library includes Java
Preferences API implementation based on the .ini file.

%package javadoc
Summary:        Java API for handling Windows ini file format
Group:          Development/Libraries/Java
Requires(post): /bin/ln
Requires(post): /bin/rm
Requires(postun): /bin/rm

%description javadoc
The [ini4j] is a simple Java API for handling configuration files in
Windows .ini format. Additionally, the library includes Java
Preferences API implementation based on the .ini file.

%prep
%setup -q

cp %{SOURCE1} build.xml

%patch -P 0 -p1

%build
%{ant} package javadoc

%install
# jar
install -d -m 755 %{buildroot}%{_javadir}
install -m 644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

# javadoc
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}/%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt
%doc NOTICE.txt

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Tue Mar 19 2024 Gus Kenion <gus.kenion@suse.com>
- Upgrade to release 0.5.4
  * No release notes available
  * Version 0.5.4 is unaffected by CVE-2022-41404 (bsc#1221526)
  * Includes Changes from version 0.5.3
    + No release notes available
  * Includes Changes from version 0.5.2
    + Fix backslash at end of line problem. Normaly backslash at
    end of line mean line concatenation. Unfortunetly when
    escaping disabled, this feature stil remain active. Now there
    is a new config option: escapeNewline. When this option true,
    it disables line concatenation. For Wini this option is set
    true by default. Fixes 3038645.
    + Added support for default value in get and fetch methods. As
    last parameter, caller may provide default value for missing
    options. Fixes 3047041.
    + Backport to java 1.4 fixed. There were a lot of problem. Now
    all junit tests are run both on current java and on 1.4 jvm.
    This way backported version is junit tested (on real 1.4 jvm)
    as the normal version. Fixes 2908623. Thanks to Markus.
    + Removed UnicodeLittle/UnicodeBig charset references because
    these break the backported version. Fixes 2778337.
    + Add BOM (byte order mark) support. Workaround on java
    BOM/UTF8 problem. Fixes 2866427. Thanks to Lilian Valero.
    + Fixed typo in Options Tutorial. Fixes 2817399.
    + Multiply macro substituton per value fixed. There were a bug
    in variable/macro substitution if more than one macro used in
    one option value. Fixes 2817403.
    + Configurable comment handling. The header comment can be
    disable/enable via Config.setHeaderComment(boolean). Also the
    whole comment handling can be disable/enable via
    Config.setComment(boolean). Fixes 2971952. Thanks to René
    Krell.
  * Rebase ini4j-java8-compat.patch onto directory structure of new
    release.
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Sep 14 2023 Fridrich Strba <fstrba@suse.com>
- Do not package information about all the properties of the
  build environment
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Wed Mar  2 2022 Fridrich Strba <fstrba@suse.com>
- Install as maven artifact
* Mon Sep 18 2017 fstrba@suse.com
- Fix build with jdk9
  * Don't specify in the build.xml source and target versions; this
    allows us to specify them by ant define
  * Specify file encoding also for javadoc
* Wed Jul 29 2015 tchvatal@suse.com
- Add patch to build with jdk8:
  * ini4j-java8-compat.patch
* Tue Jul  8 2014 tchvatal@suse.com
- Do not depend on ant-nodeps.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Wed May  6 2009 mvyskocil@suse.cz
- Initial SUSE packaging of 0.5.1 (using Mandriva spec)
